<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>OutputNullFactory</name>
    <message>
        <location filename="../outputnullfactory.cpp" line="30"/>
        <source>Null Plugin</source>
        <translation>Null Module</translation>
    </message>
    <message>
        <location filename="../outputnullfactory.cpp" line="54"/>
        <source>About Null Output Plugin</source>
        <translation>Over de Null Output Module</translation>
    </message>
    <message>
        <location filename="../outputnullfactory.cpp" line="55"/>
        <source>Qmmp Null Output Plugin</source>
        <translation>Null Output Plugin voor Qmmp</translation>
    </message>
    <message>
        <location filename="../outputnullfactory.cpp" line="56"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
